#
# spec file for package matrix
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


## Package updates
#
# * Update version in _service and this file to the most recent released one
# * Call `osc service ra`
# * Update changelog manually from
# * https://github.com/matrix-org/synapse/releases
# * Commit+submit

# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         github_user matrix-org
%define         short_name synapse
Name:           matrix-%{short_name}%{?name_ext}
Version:        0.28.1
Release:        lp150.1.1
Summary:        Matrix protocol reference homeserver
License:        Apache-2.0
Group:          Productivity/Networking/Instant Messenger
Source0:        matrix-synapse-v%{version}.tar.xz
Url:            https://github.com/matrix-org/synapse
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?_test}
BuildRequires:  matrix-%{short_name}
%else
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires(pre):  shadow
%if 0%{?suse_version} >= 1330
# alternative: create a specific "synapse" group
Requires(pre):  group(nogroup)
%endif
Requires:       python-Twisted
Requires:       python-bcrypt
Requires:       python-canonicaljson >= 1.1.3
Requires:       python-frozendict >= 0.4
Requires:       python-jsonschema >= 2.5.1
Requires:       python-msgpack-python
Requires:       python-phonenumbers >= 8.2.0
Requires:       python-signedjson >= 1.0.0
Requires:       python-unpaddedbase64 >= 1.1.0
# original from python_requirements.py
#BuildRequires:       python-PyNaCl == 0.3.0
Requires:       python-Pillow
Requires:       python-PyNaCl
Requires:       python-PyYAML
Requires:       python-Twisted >= 16.0.0
Requires:       python-blist
Requires:       python-daemonize
Requires:       python-msgpack-python >= 0.3.0
Requires:       python-pyOpenSSL >= 0.14
Requires:       python-pyasn1
Requires:       python-pydenticon
Requires:       python-pymacaroons-pynacl
Requires:       python-pysaml2 >= 3.0.0
Requires:       python-service_identity >= 1.0.0
Requires:       python-ujson
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%if "%{python_flavor}" == "python2"
Provides:       matrix-synapse = %{version}
%endif
%endif

%if 0%{?_test}
%else
%python_subpackages
%endif

%description
Synapse is a Python-based reference "homeserver" implementation of
Matrix. Matrix is a system for federated Instant Messaging and VoIP.

%prep
%if 0%{?_test}
# workaround to prevent post/install failing assuming this file for whatever
# reason
touch %{_sourcedir}/%{short_name}
%else
%setup -q -n %{name}-v%{version}
for i in \
    app/client_reader \
    app/event_creator \
    app/federation_sender \
    app/synchrotron \
    app/pusher \
    app/media_repository \
    app/homeserver \
    app/appservice \
    app/federation_reader \
    app/frontend_proxy \
    app/user_dir \
    push/pusherpool \
    util/versionstring
do
    sed -i '1d' synapse/$i.py
done
# patch the version requirement as it would be hard to supply exactly this
#  version as dependency
sed -i 's/nacl==0.3.0/nacl>=0.3.0/g' synapse/python_dependencies.py
for i in synapse/app/synctl.py scripts/move_remote_media_to_new_store.py
do
    sed -i 's@#!/usr/bin/env python@#!/usr/bin/python@g' $i
done
sed -i '1 s@#!/usr/bin/env perl@#!/usr/bin/perl@g' scripts/sync_room_to_group.pl
%endif

%build
%if 0%{?_test}
python -m synapse.app.homeserver --generate-config --server localhost --config-path homeserver.yaml --report-stats=no
# Disable the web client which would need python-matrix-synapse-angular-client
# as a dependency for this test which is not available in all repos and we do
# not want to rely on it
# https://github.com/matrix-org/synapse/issues/2113
sed -e 's/\(web_client: \).*$/\1False/' -e '/- webclient  # The bundled webclient/d' -e 's/- names: \[client, webclient\]/- names: [client]/' -i homeserver.yaml
synctl start
register_new_matrix_user --config homeserver.yaml --user opensuse --password opensuse --admin https://localhost:8448
%else
%python_build
chmod +x build/lib/synapse/app/synctl.py
%endif

%install
%if 0%{?_test}
# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else
%python_install

mkdir -p "%{buildroot}%{_sysconfdir}/synapse"
install -m 0644 contrib/systemd/log_config.yaml \
             "%{buildroot}%{_sysconfdir}/synapse"
mkdir -p %{buildroot}%{_sbindir}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rcsynapse

mkdir -p "%{buildroot}%{_unitdir}"
install -m 0644 contrib/systemd/synapse.service \
             "%{buildroot}%{_unitdir}"

mkdir -p "%{buildroot}%{_rundir}/synapse"
%python_expand %fdupes %{buildroot}%{$python_sitelib}

for p in hash_password register_new_matrix_user synapse_port_db synctl ; do
    %python_clone -a %{buildroot}%{_bindir}/$p
done
%python_clone -a %{buildroot}%{_sbindir}/rcsynapse
%python_clone -a %{buildroot}%{_unitdir}/synapse.service
%python_clone -a %{buildroot}%{_sysconfdir}/synapse/log_config.yaml

%pre
getent passwd synapse >/dev/null || \
    /usr/sbin/useradd -r -g nogroup -s /sbin/nologin -c 'Matrix Synapse' \
        -d %{_localstatedir}/lib/synapse synapse
%service_add_pre synapse.service

%post
%{python_install_alternative synctl hash_password register_new_matrix_user synapse_port_db rcsynapse synapse.service log_config.yaml}
%service_add_post synapse.service

%preun
%service_del_preun synapse.service

%postun
%python_uninstall_alternative synctl
%service_del_postun synapse.service

%files %{python_files}
%defattr(-,root,root,-)
%doc *.rst
%doc LICENSE
%dir %{_sysconfdir}/synapse
%{python_sitelib}
%python_alternative %{_bindir}/hash_password
%python_alternative %{_bindir}/register_new_matrix_user
%python_alternative %{_bindir}/synapse_port_db
%python_alternative %{_bindir}/synctl
%python_alternative %{_sbindir}/rcsynapse
%python_alternative %{_unitdir}/synapse.service
%config %python_alternative %{_sysconfdir}/synapse/log_config.yaml
%python3_only %{_bindir}/sync_room_to_group.pl
%python3_only %{_bindir}/move_remote_media_to_new_store.py

%endif

%changelog
* Fri May  4 2018 okurz@suse.com
- Update to version v0.28.1:
  * SECURITY UPDATE
    Clamp the allowed values of event depth received over federation to be
    [0, 2^63 - 1]. This mitigates an attack where malicious events
    injected with depth = 2^63 - 1 render rooms unusable. Depth is used to
    determine the cosmetic ordering of events within a room, and so the ordering
    of events in such a room will default to using stream_ordering rather than depth
    (topological_ordering).
    This is a temporary solution to mitigate abuse in the wild, whilst a long term solution
    is being implemented to improve how the depth parameter is used.
    Full details at
    https://docs.google.com/document/d/1I3fi2S-XnpO45qrpCsowZv8P8dHcNZ4fsBsbOW7KABI/edit#
    Pin Twisted to <18.4 until we stop using the private _OpenSSLECCurve API.
  * Bug Fixes:
  * Return 401 for invalid access_token on logout (PR #2938) Thanks to @dklug!
  * Return a 404 rather than a 500 on rejoining empty rooms (PR #3080)
  * fix federation_domain_whitelist (PR #3099)
  * Avoid creating events with huge numbers of prev_events (PR #3113)
  * Reject events which have lots of prev_events (PR #3118)
  * Fix quarantine media admin API and search reindex (PR #3130)
  * Fix media admin APIs (PR #3134)
  * Features:
  * Add metrics for event processing lag (PR #3090)
  * Add metrics for ResponseCache (PR #3092)
  * Changes:
  * Synapse on PyPy (PR #2760) Thanks to @Valodim!
  * move handling of auto_join_rooms to RegisterHandler (PR #2996) Thanks to @krombel!
  * Improve handling of SRV records for federation connections (PR #3016) Thanks to @silkeh!
  * Document the behaviour of ResponseCache (PR #3059)
  * Preparation for py3 (PR #3061, #3073, #3074, #3075, #3103, #3104, #3106, #3107, #3109, #3110) Thanks to @NotAFile!
  * update prometheus dashboard to use new metric names (PR #3069) Thanks to @krombel!
  * use python3-compatible prints (PR #3074) Thanks to @NotAFile!
  * Send federation events concurrently (PR #3078)
  * Limit concurrent event sends for a room (PR #3079)
  * Improve R30 stat definition (PR #3086)
  * Send events to ASes concurrently (PR #3088)
  * Refactor ResponseCache usage (PR #3093)
  * Clarify that SRV may not point to a CNAME (PR #3100) Thanks to @silkeh!
  * Use str(e) instead of e.message (PR #3103) Thanks to @NotAFile!
  * Use six.itervalues in some places (PR #3106) Thanks to @NotAFile!
  * Refactor store.have_events (PR #3117)
* Fri Apr 27 2018 okurz@suse.com
- Disable web-client for package self-test to get rid of unfulfilled dependency
* Fri Apr 20 2018 okurz@suse.com
- Introduce package self-test based on _multibuild
* Mon Apr 16 2018 okurz@suse.com
- Update to version v0.27.4:
  * Bug fixes:
  * URL quote path segments over federation (#3082)
  * Add room_id to the response of rooms/{roomId}/join (PR #2986) Thanks to @jplatte!
  * Fix replication after switch to simplejson (PR #3015)
  * Fix replication after switch to simplejson (PR #3015)
  * 404 correctly on missing paths via NoResource (PR #3022)
  * Fix error when claiming e2e keys from offline servers (PR #3034)
  * fix tests/storage/test_user_directory.py (PR #3042)
  * use PUT instead of POST for federating groups/m.join_policy (PR #3070) Thanks to @krombel!
  * postgres port script: fix state_groups_pkey error (PR #3072)
  * Features:
  * Add joinability for groups (PR #3045)
  * Implement group join API (PR #3046)
  * Add counter metrics for calculating state delta (PR #3033)
  * R30 stats (PR #3041)
  * Measure time it takes to calculate state group ID (PR #3043)
  * Add basic performance statistics to phone home (PR #3044)
  * Add response size metrics (PR #3071)
  * phone home cache size configurations (PR #3063)
  * Changes:
  * Update canonicaljson dependency (#3095)
  * Add a blurb explaining the main synapse worker (PR #2886) Thanks to @turt2live!
  * Replace old style error catching with 'as' keyword (PR #3000) Thanks to @NotAFile!
  * Use .iter* to avoid copies in StateHandler (PR #3006)
  * Linearize calls to _generate_user_id (PR #3029)
  * Remove last usage of ujson (PR #3030)
  * Use simplejson throughout (PR #3048)
  * Use static JSONEncoders (PR #3049)
  * Remove uses of events.content (PR #3060)
  * Improve database cache performance (PR #3068)
* Thu Mar 29 2018 okurz@suse.com
- Update to version v0.27.2:
  * Bug fixes:
  * Fix bug which broke TCP replication between workers (PR #3015)
  * Fix broken ldap_config config option (PR #2683) Thanks to @seckrv!
  * Fix error message when user is not allowed to unban (PR #2761) Thanks to
    @turt2live!
  * Fix publicised groups GET API (singular) over federation (PR #2772)
  * Fix user directory when using user_directory_search_all_users config
    option (PR #2803, #2831)
  * Fix error on /publicRooms when no rooms exist (PR #2827)
  * Fix bug in quarantine_media (PR #2837)
  * Fix url_previews when no Content-Type is returned from URL (PR #2845)
  * Fix rare race in sync API when joining room (PR #2944)
  * Fix slow event search, switch back from GIST to GIN indexes (PR #2769,
    [#2848])
  * Fix bug where an invalid event caused server to stop functioning
    correctly, due to parsing and serializing bugs in ujson library.
  * Features:
  * Add ability for ASes to override message send time (PR #2754)
  * Add support for custom storage providers for media repository (PR #2867,
    [#2777], #2783, #2789, #2791, #2804, #2812, #2814, #2857, #2868, #2767)
  * Add purge API features, see docs/admin_api/purge_history_api.rst for
    full details (PR #2858, #2867, #2882, #2946, #2962, #2943)
  * Add support for whitelisting 3PIDs that users can register. (PR #2813)
  * Add /room/{id}/event/{id} API (PR #2766)
  * Add an admin API to get all the media in a room (PR #2818) Thanks to
    @turt2live!
  * Add federation_domain_whitelist option (PR #2820, #2821)
  * Changes:
  * Continue to factor out processing from main process and into worker
    processes. See updated docs/workers.rst (PR #2892 - #2904, #2913, #2920
  - #2926, #2947, #2847, #2854, #2872, #2873, #2874, #2928, #2929, #2934,
    [#2856], #2976 - #2984, #2987 - #2989, #2991 - #2993, #2995, #2784)
  * Ensure state cache is used when persisting events (PR #2864, #2871,
    [#2802], #2835, #2836, #2841, #2842, #2849)
  * Change the default config to bind on both IPv4 and IPv6 on all platforms
    (PR #2435) Thanks to @silkeh!
  * No longer require a specific version of saml2 (PR #2695) Thanks to @okurz!
  * Remove verbosity/log_file from generated config (PR #2755)
  * Add and improve metrics and logging (PR #2770, #2778, #2785, #2786,
    [#2787], #2793, #2794, #2795, #2809, #2810, #2833, #2834, #2844, #2965,
    [#2927], #2975, #2790, #2796, #2838)
  * When using synctl with workers, don't start the main synapse
    automatically (PR #2774)
  * Minor performance improvements (PR #2773, #2792)
  * Use a connection pool for non-federation outbound connections (PR #2817)
  * Make it possible to run unit tests against postgres (PR #2829)
  * Update pynacl dependency to 1.2.1 or higher (PR #2888) Thanks to @bachp!
  * Remove ability for AS users to call /events and /sync (PR #2948)
  * Use bcrypt.checkpw (PR #2949) Thanks to @krombel!
- Change spec-file to use service downloaded and recompressed file directly
- Remove patch synapse_python_dependencies_allow_higher_versions_of_pysaml2.patch
  now included in upstream changes
* Sun Jan  7 2018 okurz@suse.com
- Update to version v0.26.0:
  * Bug fixes:
  * Fix database port script (PR #2673)
  * Fix internal server error on login with ldap_auth_provider (PR #2678) Thanks
    to @jkolo!
  * Fix error on sqlite 3.7 (PR #2697)
  * Fix OPTIONS on preview_url (PR #2707)
  * Fix error handling on dns lookup (PR #2711)
  * Fix wrong avatars when inviting multiple users when creating room (PR #2717)
  * Fix 500 when joining matrix-dev (PR #2719)
  * Features:
  * Add ability for ASes to publicise groups for their users (PR #2686)
  * Add all local users to the user_directory and optionally search them (PR
  * #2723)
  * Add support for custom login types for validating users (PR #2729)
  * Changes:
  * Update example Prometheus config to new format (PR #2648) Thanks to
    @krombel!
  * Rename redact_content option to include_content in Push API (PR #2650)
  * Declare support for r0.3.0 (PR #2677)
  * Improve upserts (PR #2684, #2688, #2689, #2713)
  * Improve documentation of workers (PR #2700)
  * Improve tracebacks on exceptions (PR #2705)
  * Allow guest access to group APIs for reading (PR #2715)
  * Support for posting content in federation_client script (PR #2716)
  * Delete devices and pushers on logouts etc (PR #2722)
* Mon Nov 20 2017 okurz@suse.com
- Update to version v0.25.1:
  * Bug fixes:
  * Fix login with LDAP and other password provider modules (PR #2678). Thanks to @jkolo!
  * Fix port script (PR #2673)
  * Fix port script (PR #2577)
  * Fix error when running synapse with no logfile (PR #2581)
  * Fix UI auth when deleting devices (PR #2591)
  * Fix typo when checking if user is invited to group (PR #2599)
  * Fix the port script to drop NUL values in all tables (PR #2611)
  * Fix appservices being backlogged and not receiving new events due to a bug in
    notify_interested_services (PR #2631) Thanks to @xyzz!
  * Fix updating rooms avatar/display name when modified by admin (PR #2636)
  * Thanks to @farialima!
  * Fix bug in state group storage (PR #2649)
  * Fix 500 on invalid utf-8 in request (PR #2663)
  * Features:
  * Add is_public to groups table to allow for private groups (PR #2582)
  * Add a route for determining who you are (PR #2668) Thanks to @turt2live!
  * Add more features to the password providers (PR #2608, #2610, #2620,
    [#2622], #2623, #2624, #2626, #2628, #2629)
  * Add a hook for custom rest endpoints (PR #2627)
  * Add API to update group room visibility (PR #2651)
  * Changes:
  * Ignore tags when generating URL preview descriptions (PR #2576) Thanks to
    @maximevaillancourt!
  * Register some /unstable endpoints in /r0 as well (PR #2579) Thanks to @krombel!
  * Support /keys/upload on /r0 as well as /unstable (PR #2585)
  * Front-end proxy: pass through auth header (PR #2586)
  * Allow ASes to deactivate their own users (PR #2589)
  * Remove refresh tokens (PR #2613)
  * Automatically set default displayname on register (PR #2617)
  * Log login requests (PR #2618)
  * Always return is_public in the /groups/:group_id/rooms API (PR #2630)
  * Avoid no-op media deletes (PR #2637) Thanks to @spantaleev!
  * Fix various embarrassing typos around user_directory and add some doc. (PR #2643)
  * Return whether a user is an admin within a group (PR #2647)
  * Namespace visibility options for groups (PR #2657)
  * Downcase UserIDs on registration (PR #2662)
  * Cache failures when fetching URL previews (PR #2669)
  * Add patch synapse_python_dependencies_allow_higher_versions_of_pysaml2.patch
* Tue Nov 14 2017 okurz@suse.com
- Update to version v0.24.1:
  * Bug fixes:
  * Fix updating group profiles over federation (PR #2567)
  * Fix handling SERVFAILs when doing AAAA lookups for federation (PR #2477)
  * Fix incompatibility with newer versions of ujson (PR #2483) Thanks to
    @jeremycline!
  * Fix notification keywords that start/end with non-word chars (PR #2500)
  * Fix stack overflow and logcontexts from linearizer (PR #2532)
  * Fix 500 error when fields missing from power_levels event (PR #2552)
  * Fix 500 error when we get an error handling a PDU (PR #2553)
  * Fix regression in performance of syncs (PR #2470)
  * Fix caching error in the push evaluator (PR #2332)
  * Fix bug where pusherpool didn't start and broke some rooms (PR #2342)
  * Fix port script for user directory tables (PR #2375)
  * Fix device lists notifications when user rejoins a room (PR #2443, #2449)
  * Fix sync to always send down current state events in timeline (PR #2451)
  * Fix bug where guest users were incorrectly kicked (PR #2453)
  * Fix bug talking to IPv6 only servers using SRV records (PR #2462)
  * Fix synapse_port_db failure. Thanks to Pneumaticat! (PR #1904)
  * Fix caching to not cache error responses (PR #1913)
  * Fix APIs to make kick & ban reasons work (PR #1917)
  * Fix bugs in the /keys/changes api (PR #1921)
  * Fix bug where users couldn't forget rooms they were banned from (PR #1922)
  * Fix issue with long language values in pushers API (PR #1925)
  * Fix a race in transaction queue (PR #1930)
  * Fix dynamic thumbnailing to preserve aspect ratio. Thanks to jkolo! (PR
    [#1945])
  * Fix device list update to not constantly resync (PR #1964)
  * Fix potential for huge memory usage when getting device that have
    changed (PR #1969)
  * Fix bug where pusher pool didn't start and caused issues when
    interacting with some rooms (PR #2342)
  * Fix bug with storing registration sessions that caused frequent CPU churn
    (PR #2319)
  * Fix users not getting notifications when AS listened to that user_id (PR
    [#2216]) Thanks to @slipeer!
  * Fix users without push set up not getting notifications after joining rooms
    (PR #2236)
  * Fix preview url API to trim long descriptions (PR #2243)
  * Fix bug where we used cached but unpersisted state group as prev group,
    resulting in broken state of restart (PR #2263)
  * Fix removing of pushers when using workers (PR #2267)
  * Fix CORS headers to allow Authorization header (PR #2285) Thanks to @krombel!
  * Fix bug in anonymous usage statistic reporting (PR #2281)
  * Fix API to allow clients to upload one-time-keys with new sigs (PR #2206)
  * Fix bug where users got pushed for rooms they had muted (PR #2200)
  * Fix nuke-room script to work with current schema (PR #1927) Thanks
    @zuckschwerdt!
  * Fix db port script to not assume postgres tables are in the public schema
    (PR #2024) Thanks @jerrykan!
  * Fix getting latest device IP for user with no devices (PR #2118)
  * Fix rejection of invites to unreachable servers (PR #2145)
  * Fix code for reporting old verify keys in synapse (PR #2156)
  * Fix invite state to always include all events (PR #2163)
  * Fix bug where synapse would always fetch state for any missing event (PR #2170)
  * Fix a leak with timed out HTTP connections (PR #2180)
  * Fix bug where we didn't time out HTTP requests to ASes  (PR #2192)
  * Fix joining rooms over federation where not all servers in the room saw the
    new server had joined (PR #2094)
  * Fix bug where current_state_events renamed to current_state_ids (PR #1849)
  * Fix routing loop when fetching remote media (PR #1992)
  * Fix current_state_events table to not lie (PR #1996)
  * Fix CAS login to handle PartialDownloadError (PR #1997)
  * Fix assertion to stop transaction queue getting wedged (PR #2010)
  * Fix presence to fallback to last_active_ts if it beats the last sync time.
    Thanks @Half-Shot! (PR #2014)
  * Fix bug when federation received a PDU while a room join is in progress (PR
    [#2016])
  * Fix resetting state on rejected events (PR #2025)
  * Fix installation issues in readme. Thanks @ricco386 (PR #2037)
  * Fix caching of remote servers' signature keys (PR #2042)
  * Fix some leaking log context (PR #2048, #2049, #2057, #2058)
  * Fix rejection of invites not reaching sync (PR #2056)
  * Fix bug in handling of incoming device list updates over federation.
  * Features:
  * Add Group Server (PR #2352, #2363, #2374, #2377, #2378, #2382, #2410, #2426,
    [#2430], #2454, #2471, #2472, #2544)
  * Add support for channel notifications (PR #2501)
  * Add basic implementation of backup media store (PR #2538)
  * Add config option to auto-join new users to rooms (PR #2545)
  * Add a frontend proxy worker (PR #2344)
  * Add support for event_id_only push format (PR #2450)
  * Add a PoC for filtering spammy events (PR #2456)
  * Add a config option to block all room invites (PR #2457)
  * Add a user directory API (PR #2252, and many more)
  * Add shutdown room API to remove room from local server (PR #2291)
  * Add API to quarantine media (PR #2292)
  * Add new config option to not send event contents to push servers (PR #2301)
    Thanks to @cjdelisle!
  * Add per user rate-limiting overrides (PR #2208)
  * Add config option to limit maximum number of events requested by ``/sync``
    and ``/messages`` (PR #2221) Thanks to @psaavedra!
  * Add username availability checker API (PR #2183)
  * Add read marker API (PR #2120)
  * Add delete_devices API (PR #1993)
  * Add phone number registration/login support (PR #1994, #2055)
  * Add some administration functionalities. Thanks to morteza-araby! (PR #1784)
  * Changes:
  * Make the spam checker a module (PR #2474)
  * Delete expired url cache data (PR #2478)
  * Ignore incoming events for rooms that we have left (PR #2490)
  * Allow spam checker to reject invites too (PR #2492)
  * Add room creation checks to spam checker (PR #2495)
  * Spam checking: add the invitee to user_may_invite (PR #2502)
  * Process events from federation for different rooms in parallel (PR #2520)
  * Allow error strings from spam checker (PR #2531)
  * Improve error handling for missing files in config (PR #2551)
  * Make 'affinity' package optional, as it is not supported on some platforms
  * Use bcrypt module instead of py-bcrypt (PR #2288) Thanks to @kyrias!
  * Improve performance of generating push notifications (PR #2343, #2357, #2365,
    [#2366], #2371)
  * Improve DB performance for device list handling in sync (PR #2362)
  * Include a sample prometheus config (PR #2416)
  * Document known to work postgres version (PR #2433) Thanks to @ptman!
  * Improve performance of storing user IPs (PR #2307, #2308)
  * Slightly improve performance of verifying access tokens (PR #2320)
  * Slightly improve performance of event persistence (PR #2321)
  * Increase default cache factor size from 0.1 to 0.5 (PR #2330)
  * Various performance fixes (PR #2177, #2233, #2230, #2238, #2248, #2256,
    [#2274])
  * Deduplicate sync filters (PR #2219) Thanks to @krombel!
  * Correct a typo in UPGRADE.rst (PR #2231) Thanks to @aaronraimist!
  * Add count of one time keys to sync stream (PR #2237)
  * Only store event_auth for state events (PR #2247)
  * Store URL cache preview downloads separately (PR #2299)
  * Various small performance fixes (PR #2201, #2202, #2224, #2226, #2227, #2228,
    [#2229])
  * Update username availability checker API (PR #2209, #2213)
  * When purging, don't de-delta state groups we're about to delete (PR #2214)
  * Documentation to check synapse version (PR #2215) Thanks to @hamber-dick!
  * Add an index to event_search to speed up purge history API (PR #2218)
  * Always mark remotes as up if we receive a signed request from them (PR #2190)
  * Enable guest access for the 3pl/3pid APIs (PR #1986)
  * Add setting to support TURN for guests (PR #2011)
  * Various performance improvements (PR #2075, #2076, #2080, #2083, #2108,
    [#2158], #2176, #2185)
  * Make synctl a bit more user friendly (PR #2078, #2127) Thanks @APwhitehat!
  * Replace HTTP replication with TCP replication (PR #2082, #2097, #2098,
    [#2099], #2103, #2014, #2016, #2115, #2116, #2117)
  * Support authenticated SMTP (PR #2102) Thanks @DanielDent!
  * Add a counter metric for successfully-sent transactions (PR #2121)
  * Propagate errors sensibly from proxied IS requests (PR #2147)
  * Add more granular event send metrics (PR #2178)
  * Use JSONSchema for validation of filters. Thanks @pik! (PR #1783)
  * Reread log config on SIGHUP (PR #1982)
  * Speed up public room list (PR #1989)
  * Add helpful texts to logger config options (PR #1990)
  * Minor ``/sync`` performance improvements. (PR #2002, #2013, #2022)
  * Add some debug to help diagnose weird federation issue (PR #2035)
  * Correctly limit retries for all federation requests (PR #2050, #2061)
  * Don't lock table when persisting new one time keys (PR #2053)
  * Reduce some CPU work on DB threads (PR #2054)
  * Cache hosts in room (PR #2060)
  * Batch sending of device list pokes (PR #2063)
  * Speed up persist event path in certain edge cases (PR #2070)
  * Reduce database table sizes (PR #1873, #1916, #1923, #1963)
  * Update contrib/ to not use syutil. Thanks to andrewshadura! (PR #1907)
  * Don't fetch current state when sending an event in common case (PR #1955)
* Tue Nov 14 2017 okurz@suse.com
- Update to version v0.24.1+4.632baf79:
  * Disallow capital letters in userids
  * Allow = in mxids and groupids
  * Validate group ids when parsing
  * Fix a logcontext leak in the media repo
  * Correctly wire in update group profile over federation
  * replace 'except:' with 'except Exception:'
  * fix vars named `l`
  * Bump version and changelog
  * Add jitter to validity period of attestations
  * Revert "Add jitter to validity period of attestations"
* Tue Jul  4 2017 jengelh@inai.de
- Do not suppress errors from useradd procedure.
- Trim description to the essence of the package. It is not
  supposed to be a manual or architectural document.
- Remove redundant %%clean section. Replace %%__-type macro
  indirections.
* Thu Jun 29 2017 okurz@suse.com
- Prevent conflicts between python2/3 version of packages
* Sun Jun 18 2017 okurz@suse.com
- Initial version of matrix-synapse version 0.19.2
